@@ -5,9 +5,7 @@ import (
 	"fmt"
 	"testing"
 
-	"github.com/jandedobbeleer/oh-my-posh/src/mock"
 	"github.com/jandedobbeleer/oh-my-posh/src/platform"
-	"github.com/jandedobbeleer/oh-my-posh/src/properties"
 
 	"github.com/stretchr/testify/assert"
 )
@@ -56,35 +54,32 @@ func TestHaskell(t *testing.T) {
 	}
 
 	for _, tc := range cases {
-		env := new(mock.MockedEnvironment)
+		params := &mockedLanguageParams{
+			cmd:           "ghc",
+			versionParam:  "--numeric-version",
+			versionOutput: tc.GhcVersion,
+			extension:     "*.hs",
+		}
+		env, props := getMockedLanguageEnv(params)
+
 		if tc.StackGhcMode == "always" || (tc.StackGhcMode == "package" && tc.InStackPackage) {
 			env.On("HasCommand", "stack").Return(true)
 			env.On("RunCommand", "stack", []string{"ghc", "--", "--numeric-version"}).Return(tc.StackGhcVersion, nil)
-		} else {
-			env.On("HasCommand", "ghc").Return(true)
-			env.On("RunCommand", "ghc", []string{"--numeric-version"}).Return(tc.GhcVersion, nil)
 		}
+
 		fileInfo := &platform.FileInfo{
 			Path:         "../stack.yaml",
 			ParentFolder: "./",
 			IsDir:        false,
 		}
+
 		if tc.InStackPackage {
 			var err error
 			env.On("HasParentFilePath", "stack.yaml").Return(fileInfo, err)
 		} else {
 			env.On("HasParentFilePath", "stack.yaml").Return(fileInfo, errors.New("no match"))
 		}
-		env.On("HasFiles", "*.hs").Return(true)
-		env.On("Pwd").Return("/usr/home/project")
-		env.On("Home").Return("/usr/home")
-		env.On("TemplateCache").Return(&platform.TemplateCache{
-			Env: make(map[string]string),
-		})
 
-		props := properties.Map{
-			properties.FetchVersion: true,
-		}
 		props[StackGhcMode] = tc.StackGhcMode
 
 		h := &Haskell{}
