@@ -39,53 +39,73 @@ type TerraformBlock struct {
 
 func (tf *Terraform) Enabled() bool {
 	cmd := "terraform"
-	terraformFolder := filepath.Join(tf.env.Pwd(), ".terraform")
 	fetchVersion := tf.props.GetBool(properties.FetchVersion, false)
-	if fetchVersion {
-		// known version files
-		files := []string{"versions.tf", "main.tf", "terraform.tfstate"}
-		var hasFiles bool
-		for _, file := range files {
-			if tf.env.HasFiles(file) {
-				hasFiles = true
-				break
-			}
-		}
-		fetchVersion = hasFiles
-	}
 
-	inContext := tf.env.HasFolder(terraformFolder) || fetchVersion
-	if !tf.env.HasCommand(cmd) || !inContext {
+	if !tf.env.HasCommand(cmd) || !tf.inContext(fetchVersion) {
 		return false
 	}
+
 	tf.WorkspaceName, _ = tf.env.RunCommand(cmd, "workspace", "show")
 	if !fetchVersion {
 		return true
 	}
+
 	if err := tf.setVersionFromTfFiles(); err == nil {
 		return true
 	}
+
 	tf.setVersionFromTfStateFile()
 	return true
 }
 
+func (tf *Terraform) inContext(fetchVersion bool) bool {
+	terraformFolder := filepath.Join(tf.env.Pwd(), ".terraform")
+
+	if tf.env.HasFolder(terraformFolder) {
+		return true
+	}
+
+	files := []string{".tf", ".tfplan", ".tfstate"}
+	for _, file := range files {
+		if tf.env.HasFiles(file) {
+			return true
+		}
+	}
+
+	if !fetchVersion {
+		return false
+	}
+
+	versionFiles := []string{"versions.tf", "main.tf", "terraform.tfstate"}
+	for _, file := range versionFiles {
+		if tf.env.HasFiles(file) {
+			return true
+		}
+	}
+
+	return false
+}
+
 func (tf *Terraform) setVersionFromTfFiles() error {
 	files := []string{"versions.tf", "main.tf"}
 	for _, file := range files {
 		if !tf.env.HasFiles(file) {
 			continue
 		}
+
 		parser := hclparse.NewParser()
 		content := tf.env.FileContent(file)
 		hclFile, diags := parser.ParseHCL([]byte(content), file)
 		if diags != nil {
 			continue
 		}
+
 		var config TerraFormConfig
 		diags = gohcl.DecodeBody(hclFile.Body, nil, &config)
 		if diags != nil {
 			continue
 		}
+
 		tf.TerraformBlock = *config.Terraform
 		return nil
 	}
@@ -97,6 +117,7 @@ func (tf *Terraform) setVersionFromTfStateFile() {
 	if !tf.env.HasFiles(file) {
 		return
 	}
+
 	content := tf.env.FileContent(file)
 	_ = json.Unmarshal([]byte(content), &tf.TerraformBlock)
 }
